@@ -2,9 +2,9 @@
 
 use std::collections::BTreeMap;
 
-use ruma_common::MilliSecondsSinceUnixEpoch;
-use ruma_identifiers::{ServerName, ServerSigningKeyId};
-use ruma_serde::Base64;
+use ruma_common::{
+    serde::Base64, MilliSecondsSinceUnixEpoch, OwnedServerName, OwnedServerSigningKeyId,
+};
 use serde::{Deserialize, Serialize};
 
 pub mod discover_homeserver;
@@ -12,6 +12,8 @@ pub mod get_remote_server_keys;
 pub mod get_remote_server_keys_batch;
 pub mod get_server_keys;
 pub mod get_server_version;
+#[cfg(feature = "unstable-msc3723")]
+pub mod get_server_versions;
 
 /// Public key of the homeserver for verifying digital signatures.
 #[derive(Clone, Debug, Deserialize, Serialize)]
@@ -46,24 +48,24 @@ impl OldVerifyKey {
     }
 }
 
-// Spec is wrong, all fields are required (see https://github.com/matrix-org/matrix-doc/issues/2508)
+// Spec is wrong, all fields are required (see https://github.com/matrix-org/matrix-spec/issues/613)
 /// Queried server key, signed by the notary server.
 #[derive(Clone, Debug, Deserialize, Serialize)]
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
 pub struct ServerSigningKeys {
     /// DNS name of the homeserver.
-    pub server_name: Box<ServerName>,
+    pub server_name: OwnedServerName,
 
     /// Public keys of the homeserver for verifying digital signatures.
-    pub verify_keys: BTreeMap<Box<ServerSigningKeyId>, VerifyKey>,
+    pub verify_keys: BTreeMap<OwnedServerSigningKeyId, VerifyKey>,
 
     /// Public keys that the homeserver used to use and when it stopped using them.
-    pub old_verify_keys: BTreeMap<Box<ServerSigningKeyId>, OldVerifyKey>,
+    pub old_verify_keys: BTreeMap<OwnedServerSigningKeyId, OldVerifyKey>,
 
     /// Digital signatures of this object signed using the verify_keys.
     ///
     /// Map of server name to keys by key ID.
-    pub signatures: BTreeMap<Box<ServerName>, BTreeMap<Box<ServerSigningKeyId>, String>>,
+    pub signatures: BTreeMap<OwnedServerName, BTreeMap<OwnedServerSigningKeyId, String>>,
 
     /// Timestamp when the keys should be refreshed.
     ///
@@ -75,7 +77,7 @@ impl ServerSigningKeys {
     /// Creates a new `ServerSigningKeys` with the given server name and validity timestamp.
     ///
     /// All other fields will be empty.
-    pub fn new(server_name: Box<ServerName>, valid_until_ts: MilliSecondsSinceUnixEpoch) -> Self {
+    pub fn new(server_name: OwnedServerName, valid_until_ts: MilliSecondsSinceUnixEpoch) -> Self {
         Self {
             server_name,
             verify_keys: BTreeMap::new(),
