@@ -2,8 +2,7 @@
 //!
 //! [spec]: https://spec.matrix.org/v1.2/server-server-api/#put_matrixfederationv2send_joinroomideventid
 
-use ruma_api::ruma_api;
-use ruma_identifiers::{EventId, RoomId};
+use ruma_common::{api::ruma_api, EventId, RoomId};
 use serde_json::value::RawValue as RawJsonValue;
 
 use super::RoomState;
