@@ -2,8 +2,7 @@
 //!
 //! [spec]: https://spec.matrix.org/v1.2/server-server-api/#put_matrixfederationv2send_leaveroomideventid
 
-use ruma_api::ruma_api;
-use ruma_identifiers::{EventId, RoomId};
+use ruma_common::{api::ruma_api, EventId, RoomId};
 use serde_json::value::RawValue as RawJsonValue;
 
 ruma_api! {
@@ -11,7 +10,7 @@ ruma_api! {
         description: "Submits a signed leave event to the receiving server for it to accept it into the room's graph.",
         name: "create_leave_event",
         method: PUT,
-        stable_path: "/_matrix/federation/v1/send_leave/:room_id/:event_id",
+        stable_path: "/_matrix/federation/v2/send_leave/:room_id/:event_id",
         rate_limited: false,
         authentication: ServerSignatures,
         added: 1.0,
@@ -53,7 +52,7 @@ impl Response {
 
 #[cfg(all(test, feature = "server"))]
 mod tests {
-    use ruma_api::OutgoingResponse;
+    use ruma_common::api::OutgoingResponse;
 
     use super::Response;
 
