@@ -4,11 +4,13 @@ use std::collections::BTreeMap;
 
 use js_int::UInt;
 use ruma_common::{
-    encryption::DeviceKeys, presence::PresenceState, to_device::DeviceIdOrAllDevices,
+    encryption::{CrossSigningKey, DeviceKeys},
+    events::{receipt::Receipt, AnyToDeviceEventContent, ToDeviceEventType},
+    presence::PresenceState,
+    serde::{from_raw_json_value, Raw},
+    to_device::DeviceIdOrAllDevices,
+    OwnedDeviceId, OwnedEventId, OwnedRoomId, OwnedTransactionId, OwnedUserId,
 };
-use ruma_events::{receipt::Receipt, AnyToDeviceEventContent, EventType};
-use ruma_identifiers::{DeviceId, EventId, RoomId, TransactionId, UserId};
-use ruma_serde::{from_raw_json_value, Raw};
 use serde::{de, Deserialize, Serialize};
 use serde_json::{value::RawValue as RawJsonValue, Value as JsonValue};
 
@@ -45,6 +47,11 @@ pub enum Edu {
     #[serde(rename = "m.direct_to_device")]
     DirectToDevice(DirectDeviceContent),
 
+    /// An EDU that lets servers push details to each other when one of their users updates their
+    /// cross-signing keys.
+    #[serde(rename = "m.signing_key_update")]
+    SigningKeyUpdate(SigningKeyUpdateContent),
+
     #[doc(hidden)]
     _Custom(JsonValue),
 }
@@ -70,6 +77,7 @@ impl<'de> Deserialize<'de> for Edu {
             "m.typing" => Self::Typing(from_raw_json_value(&content)?),
             "m.device_list_update" => Self::DeviceListUpdate(from_raw_json_value(&content)?),
             "m.direct_to_device" => Self::DirectToDevice(from_raw_json_value(&content)?),
+            "m.signing_key_update" => Self::SigningKeyUpdate(from_raw_json_value(&content)?),
             _ => Self::_Custom(from_raw_json_value(&content)?),
         })
     }
@@ -95,7 +103,7 @@ impl PresenceContent {
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
 pub struct PresenceUpdate {
     /// The user ID this presence EDU is for.
-    pub user_id: Box<UserId>,
+    pub user_id: OwnedUserId,
 
     /// The presence of the user.
     pub presence: PresenceState,
@@ -116,7 +124,7 @@ pub struct PresenceUpdate {
 
 impl PresenceUpdate {
     /// Creates a new `PresenceUpdate` with the given `user_id`, `presence` and `last_activity`.
-    pub fn new(user_id: Box<UserId>, presence: PresenceState, last_activity: UInt) -> Self {
+    pub fn new(user_id: OwnedUserId, presence: PresenceState, last_activity: UInt) -> Self {
         Self {
             user_id,
             presence,
@@ -133,12 +141,12 @@ impl PresenceUpdate {
 pub struct ReceiptContent {
     /// Receipts for a particular room.
     #[serde(flatten)]
-    pub receipts: BTreeMap<Box<RoomId>, ReceiptMap>,
+    pub receipts: BTreeMap<OwnedRoomId, ReceiptMap>,
 }
 
 impl ReceiptContent {
     /// Creates a new `ReceiptContent`.
-    pub fn new(receipts: BTreeMap<Box<RoomId>, ReceiptMap>) -> Self {
+    pub fn new(receipts: BTreeMap<OwnedRoomId, ReceiptMap>) -> Self {
         Self { receipts }
     }
 }
@@ -149,12 +157,12 @@ impl ReceiptContent {
 pub struct ReceiptMap {
     /// Read receipts for users in the room.
     #[serde(rename = "m.read")]
-    pub read: BTreeMap<Box<UserId>, ReceiptData>,
+    pub read: BTreeMap<OwnedUserId, ReceiptData>,
 }
 
 impl ReceiptMap {
     /// Creates a new `ReceiptMap`.
-    pub fn new(read: BTreeMap<Box<UserId>, ReceiptData>) -> Self {
+    pub fn new(read: BTreeMap<OwnedUserId, ReceiptData>) -> Self {
         Self { read }
     }
 }
@@ -167,12 +175,12 @@ pub struct ReceiptData {
     pub data: Receipt,
 
     /// The extremity event ID the user has read up to.
-    pub event_ids: Vec<Box<EventId>>,
+    pub event_ids: Vec<OwnedEventId>,
 }
 
 impl ReceiptData {
     /// Creates a new `ReceiptData`.
-    pub fn new(data: Receipt, event_ids: Vec<Box<EventId>>) -> Self {
+    pub fn new(data: Receipt, event_ids: Vec<OwnedEventId>) -> Self {
         Self { data, event_ids }
     }
 }
@@ -182,10 +190,10 @@ impl ReceiptData {
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
 pub struct TypingContent {
     /// The room where the user's typing status has been updated.
-    pub room_id: Box<RoomId>,
+    pub room_id: OwnedRoomId,
 
     /// The user ID that has had their typing status changed.
-    pub user_id: Box<UserId>,
+    pub user_id: OwnedUserId,
 
     /// Whether the user is typing in the room or not.
     pub typing: bool,
@@ -193,7 +201,7 @@ pub struct TypingContent {
 
 impl TypingContent {
     /// Creates a new `TypingContent`.
-    pub fn new(room_id: Box<RoomId>, user_id: Box<UserId>, typing: bool) -> Self {
+    pub fn new(room_id: OwnedRoomId, user_id: OwnedUserId, typing: bool) -> Self {
         Self { room_id, user_id, typing }
     }
 }
@@ -203,10 +211,10 @@ impl TypingContent {
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
 pub struct DeviceListUpdateContent {
     /// The user ID who owns the device.
-    pub user_id: Box<UserId>,
+    pub user_id: OwnedUserId,
 
     /// The ID of the device whose details are changing.
-    pub device_id: Box<DeviceId>,
+    pub device_id: OwnedDeviceId,
 
     /// The public human-readable name of this device.
     ///
@@ -234,7 +242,7 @@ pub struct DeviceListUpdateContent {
 impl DeviceListUpdateContent {
     /// Create a new `DeviceListUpdateContent` with the given `user_id`, `device_id` and
     /// `stream_id`.
-    pub fn new(user_id: Box<UserId>, device_id: Box<DeviceId>, stream_id: UInt) -> Self {
+    pub fn new(user_id: OwnedUserId, device_id: OwnedDeviceId, stream_id: UInt) -> Self {
         Self {
             user_id,
             device_id,
@@ -252,14 +260,14 @@ impl DeviceListUpdateContent {
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
 pub struct DirectDeviceContent {
     /// The user ID of the sender.
-    pub sender: Box<UserId>,
+    pub sender: OwnedUserId,
 
     /// Event type for the message.
     #[serde(rename = "type")]
-    pub ev_type: EventType,
+    pub ev_type: ToDeviceEventType,
 
     /// Unique utf8 string ID for the message, used for idempotency.
-    pub message_id: Box<TransactionId>,
+    pub message_id: OwnedTransactionId,
 
     /// The contents of the messages to be sent.
     ///
@@ -270,7 +278,11 @@ pub struct DirectDeviceContent {
 
 impl DirectDeviceContent {
     /// Creates a new `DirectDeviceContent` with the given `sender, `ev_type` and `message_id`.
-    pub fn new(sender: Box<UserId>, ev_type: EventType, message_id: Box<TransactionId>) -> Self {
+    pub fn new(
+        sender: OwnedUserId,
+        ev_type: ToDeviceEventType,
+        message_id: OwnedTransactionId,
+    ) -> Self {
         Self { sender, ev_type, message_id, messages: DirectDeviceMessages::new() }
     }
 }
@@ -279,13 +291,36 @@ impl DirectDeviceContent {
 ///
 /// Represented as a map of `{ user-ids => { device-ids => message-content } }`.
 pub type DirectDeviceMessages =
-    BTreeMap<Box<UserId>, BTreeMap<DeviceIdOrAllDevices, Raw<AnyToDeviceEventContent>>>;
+    BTreeMap<OwnedUserId, BTreeMap<DeviceIdOrAllDevices, Raw<AnyToDeviceEventContent>>>;
+
+/// The content for an `m.signing_key_update` EDU.
+#[derive(Clone, Debug, Deserialize, Serialize)]
+#[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
+pub struct SigningKeyUpdateContent {
+    /// The user ID whose cross-signing keys have changed.
+    pub user_id: OwnedUserId,
+
+    /// The user's master key, if it was updated.
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub master_key: Option<Raw<CrossSigningKey>>,
+
+    /// The users's self-signing key, if it was updated.
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub self_signing_key: Option<Raw<CrossSigningKey>>,
+}
+
+impl SigningKeyUpdateContent {
+    /// Creates a new `SigningKeyUpdateContent`.
+    pub fn new(user_id: OwnedUserId) -> Self {
+        Self { user_id, master_key: None, self_signing_key: None }
+    }
+}
 
 #[cfg(test)]
 mod test {
     use js_int::uint;
     use matches::assert_matches;
-    use ruma_identifiers::{room_id, user_id};
+    use ruma_common::{room_id, user_id};
     use serde_json::json;
 
     use super::*;
@@ -321,24 +356,26 @@ mod test {
         });
 
         let edu = serde_json::from_value::<Edu>(json.clone()).unwrap();
-        assert_matches!(
-            &edu,
-            Edu::DeviceListUpdate(DeviceListUpdateContent {
-                user_id,
-                device_id,
-                device_display_name,
-                stream_id,
-                prev_id,
-                deleted,
-                keys
-            }) if user_id == "@john:example.com"
-                && device_id == "QBUAZIFURK"
-                && device_display_name.as_deref() == Some("Mobile")
-                && *stream_id == uint!(6)
-                && prev_id.is_empty()
-                && *deleted == Some(false)
-                && keys.is_some()
-        );
+        let DeviceListUpdateContent {
+            user_id,
+            device_id,
+            device_display_name,
+            stream_id,
+            prev_id,
+            deleted,
+            keys,
+        } = match &edu {
+            Edu::DeviceListUpdate(u) => u,
+            _ => panic!("Unexpected Edu variant: {:#?}", edu),
+        };
+
+        assert_eq!(user_id, "@john:example.com");
+        assert_eq!(device_id, "QBUAZIFURK");
+        assert_eq!(device_display_name.as_deref(), Some("Mobile"));
+        assert_eq!(*stream_id, uint!(6));
+        assert_eq!(*prev_id, vec![]);
+        assert_eq!(*deleted, Some(false));
+        assert_matches!(keys, Some(_));
 
         assert_eq!(serde_json::to_value(&edu).unwrap(), json);
     }
@@ -355,24 +392,26 @@ mod test {
         });
 
         let edu = serde_json::from_value::<Edu>(json.clone()).unwrap();
-        assert_matches!(
-            &edu,
-            Edu::DeviceListUpdate(DeviceListUpdateContent {
-                user_id,
-                device_id,
-                device_display_name,
-                stream_id,
-                prev_id,
-                deleted,
-                keys
-            }) if user_id == "@john:example.com"
-                && device_id == "QBUAZIFURK"
-                && device_display_name.is_none()
-                && *stream_id == uint!(6)
-                && prev_id.is_empty()
-                && deleted.is_none()
-                && keys.is_none()
-        );
+        let DeviceListUpdateContent {
+            user_id,
+            device_id,
+            device_display_name,
+            stream_id,
+            prev_id,
+            deleted,
+            keys,
+        } = match &edu {
+            Edu::DeviceListUpdate(u) => u,
+            _ => panic!("Unexpected Edu variant: {:#?}", edu),
+        };
+
+        assert_eq!(user_id, "@john:example.com");
+        assert_eq!(device_id, "QBUAZIFURK");
+        assert_eq!(*device_display_name, None);
+        assert_eq!(*stream_id, uint!(6));
+        assert_eq!(*prev_id, vec![]);
+        assert_eq!(*deleted, None);
+        assert_matches!(keys, None);
 
         assert_eq!(serde_json::to_value(&edu).unwrap(), json);
     }
@@ -458,11 +497,64 @@ mod test {
             Edu::DirectToDevice(DirectDeviceContent {
                 sender, ev_type, message_id, messages
             }) if sender == "@john:example.com"
-                && *ev_type == EventType::RoomKeyRequest
+                && *ev_type == ToDeviceEventType::RoomKeyRequest
                 && message_id == "hiezohf6Hoo7kaev"
                 && messages.get(user_id!("@alice:example.org")).is_some()
         );
 
         assert_eq!(serde_json::to_value(&edu).unwrap(), json);
     }
+
+    #[test]
+    fn signing_key_update_edu() {
+        let json = json!({
+            "content": {
+                "master_key": {
+                    "keys": {
+                        "ed25519:alice+base64+public+key": "alice+base64+public+key",
+                        "ed25519:base64+master+public+key": "base64+master+public+key"
+                    },
+                    "signatures": {
+                        "@alice:example.com": {
+                            "ed25519:alice+base64+master+key": "signature+of+key"
+                        }
+                    },
+                    "usage": [
+                        "master"
+                    ],
+                    "user_id": "@alice:example.com"
+                },
+                "self_signing_key": {
+                    "keys": {
+                        "ed25519:alice+base64+public+key": "alice+base64+public+key",
+                        "ed25519:base64+self+signing+public+key": "base64+self+signing+master+public+key"
+                    },
+                    "signatures": {
+                        "@alice:example.com": {
+                            "ed25519:alice+base64+master+key": "signature+of+key",
+                            "ed25519:base64+master+public+key": "signature+of+self+signing+key"
+                        }
+                    },
+                    "usage": [
+                        "self_signing"
+                    ],
+                    "user_id": "@alice:example.com"
+                  },
+                "user_id": "@alice:example.com"
+            },
+            "edu_type": "m.signing_key_update"
+        });
+
+        let edu = serde_json::from_value::<Edu>(json.clone()).unwrap();
+        assert_matches!(
+            &edu,
+            Edu::SigningKeyUpdate(SigningKeyUpdateContent {
+                user_id,
+                master_key: Some(_),
+                self_signing_key: Some(_),
+            }) if user_id == "@alice:example.com"
+        );
+
+        assert_eq!(serde_json::to_value(&edu).unwrap(), json);
+    }
 }
